"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    aws_account_id: str,
    data_source_id: str,
    name: str,
    type_: str,
    data_source_parameters: Dict = None,
    credentials: Dict = None,
    permissions: List = None,
    vpc_connection_properties: Dict = None,
    ssl_properties: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a data source.

    Args:
        aws_account_id(str): The Amazon Web Services account; ID.
        data_source_id(str): An ID for the data source. This ID is unique per Region; for each Amazon Web Services account;. .
        name(str): A display name for the data source.
        type_(str): The type of the data source. Currently, the supported types for this operation are: ATHENA, AURORA, AURORA_POSTGRESQL, AMAZON_ELASTICSEARCH, MARIADB, MYSQL, POSTGRESQL, PRESTO, REDSHIFT, S3, SNOWFLAKE, SPARK, SQLSERVER, TERADATA. Use ListDataSources to return a list of all data sources.  AMAZON_ELASTICSEARCH is for Amazon managed Elasticsearch Service.
        data_source_parameters(Dict, optional): The parameters that QuickSight uses to connect to your underlying source. Defaults to None.
        credentials(Dict, optional): The credentials QuickSight that uses to connect to your underlying source. Currently, only credentials based on user name and password are supported. Defaults to None.
        permissions(List, optional): A list of resource permissions on the data source. Defaults to None.
        vpc_connection_properties(Dict, optional): Use this parameter only when you want QuickSight to use a VPC connection when connecting to your underlying source. Defaults to None.
        ssl_properties(Dict, optional): Secure Socket Layer (SSL) properties that apply when QuickSight connects to your underlying source. Defaults to None.
        tags(List, optional): Contains a map of the key-value pairs for the resource tag or tags assigned to the data source. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.data.source.init.create(
                ctx, aws_account_id=value, data_source_id=value, name=value, type_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.data.source.init.create aws_account_id=value, data_source_id=value, name=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="create_data_source",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "DataSourceId": data_source_id,
            "Name": name,
            "Type": type_,
            "DataSourceParameters": data_source_parameters,
            "Credentials": credentials,
            "Permissions": permissions,
            "VpcConnectionProperties": vpc_connection_properties,
            "SslProperties": ssl_properties,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, aws_account_id: str, data_source_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the data source permanently. This operation breaks all the datasets that reference the deleted data source.

    Args:
        aws_account_id(str): The Amazon Web Services account; ID.
        data_source_id(str): The ID of the data source. This ID is unique per Region; for each Amazon Web Services account;.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.data.source.init.delete(
                ctx, aws_account_id=value, data_source_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.data.source.init.delete aws_account_id=value, data_source_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="delete_data_source",
        op_kwargs={"AwsAccountId": aws_account_id, "DataSourceId": data_source_id},
    )


async def describe(hub, ctx, aws_account_id: str, data_source_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a data source.

    Args:
        aws_account_id(str): The Amazon Web Services account; ID.
        data_source_id(str): The ID of the data source. This ID is unique per Region; for each Amazon Web Services account;.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.data.source.init.describe(
                ctx, aws_account_id=value, data_source_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.data.source.init.describe aws_account_id=value, data_source_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="describe_data_source",
        op_kwargs={"AwsAccountId": aws_account_id, "DataSourceId": data_source_id},
    )


async def list_all(
    hub, ctx, aws_account_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists data sources in current Region; that belong to this Amazon Web Services account;.

    Args:
        aws_account_id(str): The Amazon Web Services account; ID.
        next_token(str, optional): The token for the next set of results, or null if there are no more results. Defaults to None.
        max_results(int, optional): The maximum number of results to be returned per request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.data.source.init.list_all(ctx, aws_account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.data.source.init.list_all aws_account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="list_data_sources",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    aws_account_id: str,
    data_source_id: str,
    name: str,
    data_source_parameters: Dict = None,
    credentials: Dict = None,
    vpc_connection_properties: Dict = None,
    ssl_properties: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a data source.

    Args:
        aws_account_id(str): The Amazon Web Services account; ID.
        data_source_id(str): The ID of the data source. This ID is unique per Region; for each Amazon Web Services account;. .
        name(str): A display name for the data source.
        data_source_parameters(Dict, optional): The parameters that QuickSight uses to connect to your underlying source. Defaults to None.
        credentials(Dict, optional): The credentials that QuickSight that uses to connect to your underlying source. Currently, only credentials based on user name and password are supported. Defaults to None.
        vpc_connection_properties(Dict, optional): Use this parameter only when you want QuickSight to use a VPC connection when connecting to your underlying source. Defaults to None.
        ssl_properties(Dict, optional): Secure Socket Layer (SSL) properties that apply when QuickSight connects to your underlying source. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.data.source.init.update(
                ctx, aws_account_id=value, data_source_id=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.data.source.init.update aws_account_id=value, data_source_id=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="update_data_source",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "DataSourceId": data_source_id,
            "Name": name,
            "DataSourceParameters": data_source_parameters,
            "Credentials": credentials,
            "VpcConnectionProperties": vpc_connection_properties,
            "SslProperties": ssl_properties,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    configuration_aggregator_name: str,
    config_rule_name: str,
    account_id: str,
    aws_region: str,
    compliance_type: str = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the evaluation results for the specified AWS Config rule for a specific resource in a rule. The results indicate which AWS resources were evaluated by the rule, when each resource was last evaluated, and whether each resource complies with the rule.   The results can return an empty result page. But if you have a nextToken, the results are displayed on the next page.

    Args:
        configuration_aggregator_name(str): The name of the configuration aggregator.
        config_rule_name(str): The name of the AWS Config rule for which you want compliance information.
        account_id(str): The 12-digit account ID of the source account.
        aws_region(str): The source region from where the data is aggregated.
        compliance_type(str, optional): The resource compliance status.  For the GetAggregateComplianceDetailsByConfigRuleRequest data type, AWS Config supports only the COMPLIANT and NON_COMPLIANT. AWS Config does not support the NOT_APPLICABLE and INSUFFICIENT_DATA values. . Defaults to None.
        limit(int, optional): The maximum number of evaluation results returned on each page. The default is 50. You cannot specify a number greater than 100. If you specify 0, AWS Config uses the default. Defaults to None.
        next_token(str, optional): The nextToken string returned on a previous page that you use to get the next page of results in a paginated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.aggregate.compliance.detail_by_config_rule.get(
                ctx,
                configuration_aggregator_name=value,
                config_rule_name=value,
                account_id=value,
                aws_region=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.aggregate.compliance.detail_by_config_rule.get configuration_aggregator_name=value, config_rule_name=value, account_id=value, aws_region=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="get_aggregate_compliance_details_by_config_rule",
        op_kwargs={
            "ConfigurationAggregatorName": configuration_aggregator_name,
            "ConfigRuleName": config_rule_name,
            "AccountId": account_id,
            "AwsRegion": aws_region,
            "ComplianceType": compliance_type,
            "Limit": limit,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, queue_url: str, receipt_handle: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified message from the specified queue. To select the message to delete, use the ReceiptHandle of the message (not the MessageId which you receive when you send the message). Amazon SQS can delete a message from a queue even if a visibility timeout setting causes the message to be locked by another consumer. Amazon SQS automatically deletes messages left in a queue longer than the retention period configured for the queue.   The ReceiptHandle is associated with a specific instance of receiving a message. If you receive a message more than once, the ReceiptHandle is different each time you receive a message. When you use the DeleteMessage action, you must provide the most recently received ReceiptHandle for the message (otherwise, the request succeeds, but the message might not be deleted). For standard queues, it is possible to receive a message even after you delete it. This might happen on rare occasions if one of the servers which stores a copy of the message is unavailable when you send the request to delete the message. The copy remains on the server and might be returned to you during a subsequent receive request. You should ensure that your application is idempotent, so that receiving a message more than once does not cause issues.

    Args:
        queue_url(str): The URL of the Amazon SQS queue from which messages are deleted. Queue URLs and names are case-sensitive.
        receipt_handle(str): The receipt handle associated with the message to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sqs.message.init.delete(
                ctx, queue_url=value, receipt_handle=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sqs.message.init.delete queue_url=value, receipt_handle=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sqs",
        operation="delete_message",
        op_kwargs={"QueueUrl": queue_url, "ReceiptHandle": receipt_handle},
    )


async def receive(
    hub,
    ctx,
    queue_url: str,
    attribute_names: List = None,
    message_attribute_names: List = None,
    max_number_of_messages: int = None,
    visibility_timeout: int = None,
    wait_time_seconds: int = None,
    receive_request_attempt_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves one or more messages (up to 10), from the specified queue. Using the WaitTimeSeconds parameter enables long-poll support. For more information, see Amazon SQS Long Polling in the Amazon SQS Developer Guide.  Short poll is the default behavior where a weighted random set of machines is sampled on a ReceiveMessage call. Thus, only the messages on the sampled machines are returned. If the number of messages in the queue is small (fewer than 1,000), you most likely get fewer messages than you requested per ReceiveMessage call. If the number of messages in the queue is extremely small, you might not receive any messages in a particular ReceiveMessage response. If this happens, repeat the request.  For each message returned, the response includes the following:   The message body.   An MD5 digest of the message body. For information about MD5, see RFC1321.   The MessageId you received when you sent the message to the queue.   The receipt handle.   The message attributes.   An MD5 digest of the message attributes.   The receipt handle is the identifier you must provide when deleting the message. For more information, see Queue and Message Identifiers in the Amazon SQS Developer Guide. You can provide the VisibilityTimeout parameter in your request. The parameter is applied to the messages that Amazon SQS returns in the response. If you don't include the parameter, the overall visibility timeout for the queue is used for the returned messages. For more information, see Visibility Timeout in the Amazon SQS Developer Guide. A message that isn't deleted or a message whose visibility isn't extended before the visibility timeout expires counts as a failed receive. Depending on the configuration of the queue, the message might be sent to the dead-letter queue.  In the future, new attributes might be added. If you write code that calls this action, we recommend that you structure your code so that it can handle new attributes gracefully.

    Args:
        queue_url(str): The URL of the Amazon SQS queue from which messages are received. Queue URLs and names are case-sensitive.
        attribute_names(List, optional): A list of attributes that need to be returned along with each message. These attributes include:    All – Returns all values.    ApproximateFirstReceiveTimestamp – Returns the time the message was first received from the queue (epoch time in milliseconds).    ApproximateReceiveCount – Returns the number of times a message has been received across all queues but not deleted.    AWSTraceHeader – Returns the X-Ray trace header string.     SenderId    For an IAM user, returns the IAM user ID, for example ABCDEFGHI1JKLMNOPQ23R.   For an IAM role, returns the IAM role ID, for example ABCDE1F2GH3I4JK5LMNOP:i-a123b456.      SentTimestamp – Returns the time the message was sent to the queue (epoch time in milliseconds).    MessageDeduplicationId – Returns the value provided by the producer that calls the  SendMessage  action.    MessageGroupId – Returns the value provided by the producer that calls the  SendMessage  action. Messages with the same MessageGroupId are returned in sequence.    SequenceNumber – Returns the value provided by Amazon SQS.  . Defaults to None.
        message_attribute_names(List, optional): The name of the message attribute, where N is the index.   The name can contain alphanumeric characters and the underscore (_), hyphen (-), and period (.).   The name is case-sensitive and must be unique among all attribute names for the message.   The name must not start with AWS-reserved prefixes such as AWS. or Amazon. (or any casing variants).   The name must not start or end with a period (.), and it should not have periods in succession (..).   The name can be up to 256 characters long.   When using ReceiveMessage, you can send a list of attribute names to receive, or you can return all of the attributes by specifying All or .* in your request. You can also use all message attributes starting with a prefix, for example bar.*. Defaults to None.
        max_number_of_messages(int, optional): The maximum number of messages to return. Amazon SQS never returns more messages than this value (however, fewer messages might be returned). Valid values: 1 to 10. Default: 1. Defaults to None.
        visibility_timeout(int, optional): The duration (in seconds) that the received messages are hidden from subsequent retrieve requests after being retrieved by a ReceiveMessage request. Defaults to None.
        wait_time_seconds(int, optional): The duration (in seconds) for which the call waits for a message to arrive in the queue before returning. If a message is available, the call returns sooner than WaitTimeSeconds. If no messages are available and the wait time expires, the call returns successfully with an empty list of messages.  To avoid HTTP errors, ensure that the HTTP response timeout for ReceiveMessage requests is longer than the WaitTimeSeconds parameter. For example, with the Java SDK, you can set HTTP transport settings using the  NettyNioAsyncHttpClient for asynchronous clients, or the  ApacheHttpClient for synchronous clients.  . Defaults to None.
        receive_request_attempt_id(str, optional): This parameter applies only to FIFO (first-in-first-out) queues. The token used for deduplication of ReceiveMessage calls. If a networking issue occurs after a ReceiveMessage action, and instead of a response you receive a generic error, it is possible to retry the same action with an identical ReceiveRequestAttemptId to retrieve the same set of messages, even if their visibility timeout has not yet expired.   You can use ReceiveRequestAttemptId only for 5 minutes after a ReceiveMessage action.   When you set FifoQueue, a caller of the ReceiveMessage action can provide a ReceiveRequestAttemptId explicitly.   If a caller of the ReceiveMessage action doesn't provide a ReceiveRequestAttemptId, Amazon SQS generates a ReceiveRequestAttemptId.   It is possible to retry the ReceiveMessage action with the same ReceiveRequestAttemptId if none of the messages have been modified (deleted or had their visibility changes).   During a visibility timeout, subsequent calls with the same ReceiveRequestAttemptId return the same messages and receipt handles. If a retry occurs within the deduplication interval, it resets the visibility timeout. For more information, see Visibility Timeout in the Amazon SQS Developer Guide.  If a caller of the ReceiveMessage action still processes messages when the visibility timeout expires and messages become visible, another worker consuming from the same queue can receive the same messages and therefore process duplicates. Also, if a consumer whose message processing time is longer than the visibility timeout tries to delete the processed messages, the action fails with an error. To mitigate this effect, ensure that your application observes a safe threshold before the visibility timeout expires and extend the visibility timeout as necessary.    While messages with a particular MessageGroupId are invisible, no more messages belonging to the same MessageGroupId are returned until the visibility timeout expires. You can still receive messages with another MessageGroupId as long as it is also visible.   If a caller of ReceiveMessage can't track the ReceiveRequestAttemptId, no retries work until the original visibility timeout expires. As a result, delays might occur but the messages in the queue remain in a strict order.   The maximum length of ReceiveRequestAttemptId is 128 characters. ReceiveRequestAttemptId can contain alphanumeric characters (a-z, A-Z, 0-9) and punctuation (!"#$%&'()*+,-./:;<=>?@[\]^_`{|}~). For best practices of using ReceiveRequestAttemptId, see Using the ReceiveRequestAttemptId Request Parameter in the Amazon SQS Developer Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sqs.message.init.receive(ctx, queue_url=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sqs.message.init.receive queue_url=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sqs",
        operation="receive_message",
        op_kwargs={
            "QueueUrl": queue_url,
            "AttributeNames": attribute_names,
            "MessageAttributeNames": message_attribute_names,
            "MaxNumberOfMessages": max_number_of_messages,
            "VisibilityTimeout": visibility_timeout,
            "WaitTimeSeconds": wait_time_seconds,
            "ReceiveRequestAttemptId": receive_request_attempt_id,
        },
    )


async def send(
    hub,
    ctx,
    queue_url: str,
    message_body: str,
    delay_seconds: int = None,
    message_attributes: Dict = None,
    message_system_attributes: Dict = None,
    message_deduplication_id: str = None,
    message_group_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Delivers a message to the specified queue.  A message can include only XML, JSON, and unformatted text. The following Unicode characters are allowed:  #x9 | #xA | #xD | #x20 to #xD7FF | #xE000 to #xFFFD | #x10000 to #x10FFFF  Any characters not included in this list will be rejected. For more information, see the W3C specification for characters.

    Args:
        queue_url(str): The URL of the Amazon SQS queue to which a message is sent. Queue URLs and names are case-sensitive.
        message_body(str): The message to send. The minimum size is one character. The maximum size is 256 KB.  A message can include only XML, JSON, and unformatted text. The following Unicode characters are allowed:  #x9 | #xA | #xD | #x20 to #xD7FF | #xE000 to #xFFFD | #x10000 to #x10FFFF  Any characters not included in this list will be rejected. For more information, see the W3C specification for characters. .
        delay_seconds(int, optional):  The length of time, in seconds, for which to delay a specific message. Valid values: 0 to 900. Maximum: 15 minutes. Messages with a positive DelaySeconds value become available for processing after the delay period is finished. If you don't specify a value, the default value for the queue applies.   When you set FifoQueue, you can't set DelaySeconds per message. You can set this parameter only on a queue level. . Defaults to None.
        message_attributes(Dict, optional): Each message attribute consists of a Name, Type, and Value. For more information, see Amazon SQS message attributes in the Amazon SQS Developer Guide. Defaults to None.
        message_system_attributes(Dict, optional): The message system attribute to send. Each message system attribute consists of a Name, Type, and Value.    Currently, the only supported message system attribute is AWSTraceHeader. Its type must be String and its value must be a correctly formatted X-Ray trace header string.   The size of a message system attribute doesn't count towards the total size of a message.   . Defaults to None.
        message_deduplication_id(str, optional): This parameter applies only to FIFO (first-in-first-out) queues. The token used for deduplication of sent messages. If a message with a particular MessageDeduplicationId is sent successfully, any messages sent with the same MessageDeduplicationId are accepted successfully but aren't delivered during the 5-minute deduplication interval. For more information, see  Exactly-once processing in the Amazon SQS Developer Guide.   Every message must have a unique MessageDeduplicationId,   You may provide a MessageDeduplicationId explicitly.   If you aren't able to provide a MessageDeduplicationId and you enable ContentBasedDeduplication for your queue, Amazon SQS uses a SHA-256 hash to generate the MessageDeduplicationId using the body of the message (but not the attributes of the message).    If you don't provide a MessageDeduplicationId and the queue doesn't have ContentBasedDeduplication set, the action fails with an error.   If the queue has ContentBasedDeduplication set, your MessageDeduplicationId overrides the generated one.     When ContentBasedDeduplication is in effect, messages with identical content sent within the deduplication interval are treated as duplicates and only one copy of the message is delivered.   If you send one message with ContentBasedDeduplication enabled and then another message with a MessageDeduplicationId that is the same as the one generated for the first MessageDeduplicationId, the two messages are treated as duplicates and only one copy of the message is delivered.     The MessageDeduplicationId is available to the consumer of the message (this can be useful for troubleshooting delivery issues). If a message is sent successfully but the acknowledgement is lost and the message is resent with the same MessageDeduplicationId after the deduplication interval, Amazon SQS can't detect duplicate messages. Amazon SQS continues to keep track of the message deduplication ID even after the message is received and deleted.  The maximum length of MessageDeduplicationId is 128 characters. MessageDeduplicationId can contain alphanumeric characters (a-z, A-Z, 0-9) and punctuation (!"#$%&'()*+,-./:;<=>?@[\]^_`{|}~). For best practices of using MessageDeduplicationId, see Using the MessageDeduplicationId Property in the Amazon SQS Developer Guide. Defaults to None.
        message_group_id(str, optional): This parameter applies only to FIFO (first-in-first-out) queues. The tag that specifies that a message belongs to a specific message group. Messages that belong to the same message group are processed in a FIFO manner (however, messages in different message groups might be processed out of order). To interleave multiple ordered streams within a single queue, use MessageGroupId values (for example, session data for multiple users). In this scenario, multiple consumers can process the queue, but the session data of each user is processed in a FIFO fashion.   You must associate a non-empty MessageGroupId with a message. If you don't provide a MessageGroupId, the action fails.    ReceiveMessage might return messages with multiple MessageGroupId values. For each MessageGroupId, the messages are sorted by time sent. The caller can't specify a MessageGroupId.   The length of MessageGroupId is 128 characters. Valid values: alphanumeric characters and punctuation (!"#$%&'()*+,-./:;<=>?@[\]^_`{|}~). For best practices of using MessageGroupId, see Using the MessageGroupId Property in the Amazon SQS Developer Guide.   MessageGroupId is required for FIFO queues. You can't use it for Standard queues. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sqs.message.init.send(ctx, queue_url=value, message_body=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sqs.message.init.send queue_url=value, message_body=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sqs",
        operation="send_message",
        op_kwargs={
            "QueueUrl": queue_url,
            "MessageBody": message_body,
            "DelaySeconds": delay_seconds,
            "MessageAttributes": message_attributes,
            "MessageSystemAttributes": message_system_attributes,
            "MessageDeduplicationId": message_deduplication_id,
            "MessageGroupId": message_group_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, findings: List) -> Dict:
    r"""
    **Autogenerated function**

    Imports security findings generated from an integrated product into Security Hub. This action is requested by the integrated product to import its findings into Security Hub. The maximum allowed size for a finding is 240 Kb. An error is returned for any finding larger than 240 Kb. After a finding is created, BatchImportFindings cannot be used to update the following finding fields and objects, which Security Hub customers use to manage their investigation workflow.    Note     UserDefinedFields     VerificationState     Workflow    Finding providers also should not use BatchImportFindings to update the following attributes.    Confidence     Criticality     RelatedFindings     Severity     Types    Instead, finding providers use FindingProviderFields to provide values for these attributes.

    Args:
        findings(List): A list of findings to import. To successfully import a finding, it must follow the Amazon Web Services Security Finding Format. Maximum of 100 findings per request.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.import_finding.init.batch(ctx, findings=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.import_finding.init.batch findings=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="batch_import_findings",
        op_kwargs={"Findings": findings},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    db_security_group_name: str,
    db_security_group_description: str,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new DB security group. DB security groups control access to a DB instance.  A DB security group controls access to EC2-Classic DB instances that are not in a VPC.

    Args:
        db_security_group_name(str): The name for the DB security group. This value is stored as a lowercase string. Constraints:   Must be 1 to 255 letters, numbers, or hyphens.   First character must be a letter   Can't end with a hyphen or contain two consecutive hyphens   Must not be "Default"   Example: mysecuritygroup .
        db_security_group_description(str): The description for the DB security group.
        tags(List, optional): Tags to assign to the DB security group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.security_group.init.create(
                ctx, db_security_group_name=value, db_security_group_description=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.security_group.init.create db_security_group_name=value, db_security_group_description=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="create_db_security_group",
        op_kwargs={
            "DBSecurityGroupName": db_security_group_name,
            "DBSecurityGroupDescription": db_security_group_description,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, db_security_group_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a DB security group.  The specified DB security group must not be associated with any DB instances.

    Args:
        db_security_group_name(str): The name of the DB security group to delete.  You can't delete the default DB security group.  Constraints:   Must be 1 to 255 letters, numbers, or hyphens.   First character must be a letter   Can't end with a hyphen or contain two consecutive hyphens   Must not be "Default"  .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.security_group.init.delete(
                ctx, db_security_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.security_group.init.delete db_security_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="delete_db_security_group",
        op_kwargs={"DBSecurityGroupName": db_security_group_name},
    )


async def describe_all(
    hub,
    ctx,
    db_security_group_name: str = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of DBSecurityGroup descriptions. If a DBSecurityGroupName is specified, the list will contain only the descriptions of the specified DB security group.

    Args:
        db_security_group_name(str, optional): The name of the DB security group to return details for. Defaults to None.
        filters(List, optional): This parameter isn't currently supported. Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that you can retrieve the remaining results.  Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous DescribeDBSecurityGroups request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.security_group.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.security_group.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="describe_db_security_groups",
        op_kwargs={
            "DBSecurityGroupName": db_security_group_name,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def accept(
    hub, ctx, resource_share_invitation_arn: str, client_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Accepts an invitation to a resource share from another AWS account.

    Args:
        resource_share_invitation_arn(str): The Amazon Resource Name (ARN) of the invitation.
        client_token(str, optional): A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ram.resource.share.invitation.accept(
                ctx, resource_share_invitation_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ram.resource.share.invitation.accept resource_share_invitation_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ram",
        operation="accept_resource_share_invitation",
        op_kwargs={
            "resourceShareInvitationArn": resource_share_invitation_arn,
            "clientToken": client_token,
        },
    )


async def get_all(
    hub,
    ctx,
    resource_share_invitation_arns: List = None,
    resource_share_arns: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the invitations that you have received for resource shares.

    Args:
        resource_share_invitation_arns(List, optional): The Amazon Resource Names (ARN) of the invitations. Defaults to None.
        resource_share_arns(List, optional): The Amazon Resource Names (ARN) of the resource shares. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ram.resource.share.invitation.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ram.resource.share.invitation.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ram",
        operation="get_resource_share_invitations",
        op_kwargs={
            "resourceShareInvitationArns": resource_share_invitation_arns,
            "resourceShareArns": resource_share_arns,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def reject(
    hub, ctx, resource_share_invitation_arn: str, client_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Rejects an invitation to a resource share from another AWS account.

    Args:
        resource_share_invitation_arn(str): The Amazon Resource Name (ARN) of the invitation.
        client_token(str, optional): A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ram.resource.share.invitation.reject(
                ctx, resource_share_invitation_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ram.resource.share.invitation.reject resource_share_invitation_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ram",
        operation="reject_resource_share_invitation",
        op_kwargs={
            "resourceShareInvitationArn": resource_share_invitation_arn,
            "clientToken": client_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    infrastructure_configuration_arn: str,
    client_token: str,
    description: str = None,
    image_recipe_arn: str = None,
    container_recipe_arn: str = None,
    distribution_configuration_arn: str = None,
    image_tests_configuration: Dict = None,
    enhanced_image_metadata_enabled: bool = None,
    schedule: Dict = None,
    status: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Creates a new image pipeline. Image pipelines enable you to automate the creation and distribution of images.

    Args:
        name(str):  The name of the image pipeline.
        description(str, optional):  The description of the image pipeline. Defaults to None.
        image_recipe_arn(str, optional):  The Amazon Resource Name (ARN) of the image recipe that will be used to configure images created by this image pipeline. Defaults to None.
        container_recipe_arn(str, optional): The Amazon Resource Name (ARN) of the container recipe that is used to configure images created by this container pipeline. Defaults to None.
        infrastructure_configuration_arn(str):  The Amazon Resource Name (ARN) of the infrastructure configuration that will be used to build images created by this image pipeline.
        distribution_configuration_arn(str, optional):  The Amazon Resource Name (ARN) of the distribution configuration that will be used to configure and distribute images created by this image pipeline. Defaults to None.
        image_tests_configuration(Dict, optional):  The image test configuration of the image pipeline. Defaults to None.
        enhanced_image_metadata_enabled(bool, optional):  Collects additional information about the image being created, including the operating system (OS) version and package list. This information is used to enhance the overall experience of using EC2 Image Builder. Enabled by default. Defaults to None.
        schedule(Dict, optional):  The schedule of the image pipeline. Defaults to None.
        status(str, optional):  The status of the image pipeline. Defaults to None.
        tags(Dict, optional):  The tags of the image pipeline. Defaults to None.
        client_token(str):  The idempotency token used to make this request idempotent.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.image.pipeline.init.create(
                ctx, name=value, infrastructure_configuration_arn=value, client_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.image.pipeline.init.create name=value, infrastructure_configuration_arn=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="create_image_pipeline",
        op_kwargs={
            "name": name,
            "description": description,
            "imageRecipeArn": image_recipe_arn,
            "containerRecipeArn": container_recipe_arn,
            "infrastructureConfigurationArn": infrastructure_configuration_arn,
            "distributionConfigurationArn": distribution_configuration_arn,
            "imageTestsConfiguration": image_tests_configuration,
            "enhancedImageMetadataEnabled": enhanced_image_metadata_enabled,
            "schedule": schedule,
            "status": status,
            "tags": tags,
            "clientToken": client_token,
        },
    )


async def delete(hub, ctx, image_pipeline_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     Deletes an image pipeline.

    Args:
        image_pipeline_arn(str): The Amazon Resource Name (ARN) of the image pipeline to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.image.pipeline.init.delete(
                ctx, image_pipeline_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.image.pipeline.init.delete image_pipeline_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="delete_image_pipeline",
        op_kwargs={"imagePipelineArn": image_pipeline_arn},
    )


async def get(hub, ctx, image_pipeline_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     Gets an image pipeline.

    Args:
        image_pipeline_arn(str): The Amazon Resource Name (ARN) of the image pipeline that you want to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.image.pipeline.init.get(
                ctx, image_pipeline_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.image.pipeline.init.get image_pipeline_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="get_image_pipeline",
        op_kwargs={"imagePipelineArn": image_pipeline_arn},
    )


async def list_all(
    hub, ctx, filters: List = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of image pipelines.

    Args:
        filters(List, optional): The filters. Defaults to None.
        max_results(int, optional): The maximum items to return in a request. Defaults to None.
        next_token(str, optional): A token to specify where to start paginating. This is the NextToken from a previously truncated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.image.pipeline.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.image.pipeline.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="list_image_pipelines",
        op_kwargs={
            "filters": filters,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    image_pipeline_arn: str,
    infrastructure_configuration_arn: str,
    client_token: str,
    description: str = None,
    image_recipe_arn: str = None,
    container_recipe_arn: str = None,
    distribution_configuration_arn: str = None,
    image_tests_configuration: Dict = None,
    enhanced_image_metadata_enabled: bool = None,
    schedule: Dict = None,
    status: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Updates an image pipeline. Image pipelines enable you to automate the creation and distribution of images.  UpdateImagePipeline does not support selective updates for the pipeline. You must specify all of the required properties in the update request, not just the properties that have changed.

    Args:
        image_pipeline_arn(str): The Amazon Resource Name (ARN) of the image pipeline that you want to update.
        description(str, optional): The description of the image pipeline. Defaults to None.
        image_recipe_arn(str, optional): The Amazon Resource Name (ARN) of the image recipe that will be used to configure images updated by this image pipeline. Defaults to None.
        container_recipe_arn(str, optional): The Amazon Resource Name (ARN) of the container pipeline to update. Defaults to None.
        infrastructure_configuration_arn(str): The Amazon Resource Name (ARN) of the infrastructure configuration that will be used to build images updated by this image pipeline.
        distribution_configuration_arn(str, optional): The Amazon Resource Name (ARN) of the distribution configuration that will be used to configure and distribute images updated by this image pipeline. Defaults to None.
        image_tests_configuration(Dict, optional): The image test configuration of the image pipeline. Defaults to None.
        enhanced_image_metadata_enabled(bool, optional):  Collects additional information about the image being created, including the operating system (OS) version and package list. This information is used to enhance the overall experience of using EC2 Image Builder. Enabled by default. Defaults to None.
        schedule(Dict, optional): The schedule of the image pipeline. Defaults to None.
        status(str, optional): The status of the image pipeline. Defaults to None.
        client_token(str): The idempotency token used to make this request idempotent.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.image.pipeline.init.update(
                ctx,
                image_pipeline_arn=value,
                infrastructure_configuration_arn=value,
                client_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.image.pipeline.init.update image_pipeline_arn=value, infrastructure_configuration_arn=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="update_image_pipeline",
        op_kwargs={
            "imagePipelineArn": image_pipeline_arn,
            "description": description,
            "imageRecipeArn": image_recipe_arn,
            "containerRecipeArn": container_recipe_arn,
            "infrastructureConfigurationArn": infrastructure_configuration_arn,
            "distributionConfigurationArn": distribution_configuration_arn,
            "imageTestsConfiguration": image_tests_configuration,
            "enhancedImageMetadataEnabled": enhanced_image_metadata_enabled,
            "schedule": schedule,
            "status": status,
            "clientToken": client_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    device_definition_id: str,
    amzn_client_token: str = None,
    devices: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a version of a device definition that has already been defined.

    Args:
        amzn_client_token(str, optional): A client token used to correlate requests and responses. Defaults to None.
        device_definition_id(str): The ID of the device definition.
        devices(List, optional): A list of devices in the definition version. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.device_definition.version.create(
                ctx, device_definition_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.device_definition.version.create device_definition_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="create_device_definition_version",
        op_kwargs={
            "AmznClientToken": amzn_client_token,
            "DeviceDefinitionId": device_definition_id,
            "Devices": devices,
        },
    )


async def get(
    hub,
    ctx,
    device_definition_id: str,
    device_definition_version_id: str,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a device definition version.

    Args:
        device_definition_id(str): The ID of the device definition.
        device_definition_version_id(str): The ID of the device definition version. This value maps to the ''Version'' property of the corresponding ''VersionInformation'' object, which is returned by ''ListDeviceDefinitionVersions'' requests. If the version is the last one that was associated with a device definition, the value also maps to the ''LatestVersion'' property of the corresponding ''DefinitionInformation'' object.
        next_token(str, optional): The token for the next set of results, or ''null'' if there are no additional results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.device_definition.version.get(
                ctx, device_definition_id=value, device_definition_version_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.device_definition.version.get device_definition_id=value, device_definition_version_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="get_device_definition_version",
        op_kwargs={
            "DeviceDefinitionId": device_definition_id,
            "DeviceDefinitionVersionId": device_definition_version_id,
            "NextToken": next_token,
        },
    )


async def list_all(
    hub, ctx, device_definition_id: str, max_results: str = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the versions of a device definition.

    Args:
        device_definition_id(str): The ID of the device definition.
        max_results(str, optional): The maximum number of results to be returned per request. Defaults to None.
        next_token(str, optional): The token for the next set of results, or ''null'' if there are no additional results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.device_definition.version.list_all(
                ctx, device_definition_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.device_definition.version.list_all device_definition_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="list_device_definition_versions",
        op_kwargs={
            "DeviceDefinitionId": device_definition_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, api_name: str, stream_name: str = None, stream_arn: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets an endpoint for a specified stream for either reading or writing. Use this endpoint in your application to read from the specified stream (using the GetMedia or GetMediaForFragmentList operations) or write to it (using the PutMedia operation).   The returned endpoint does not have the API name appended. The client needs to add the API name to the returned endpoint.  In the request, specify the stream either by StreamName or StreamARN.

    Args:
        stream_name(str, optional): The name of the stream that you want to get the endpoint for. You must specify either this parameter or a StreamARN in the request. Defaults to None.
        stream_arn(str, optional): The Amazon Resource Name (ARN) of the stream that you want to get the endpoint for. You must specify either this parameter or a StreamName in the request. . Defaults to None.
        api_name(str): The name of the API action for which to get an endpoint.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisvideo.data.endpoint.get(ctx, api_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisvideo.data.endpoint.get api_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisvideo",
        operation="get_data_endpoint",
        op_kwargs={
            "StreamName": stream_name,
            "StreamARN": stream_arn,
            "APIName": api_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def simulate(
    hub,
    ctx,
    policy_source_arn: str,
    action_names: List,
    policy_input_list: List = None,
    permissions_boundary_policy_input_list: List = None,
    resource_arns: List = None,
    resource_policy: str = None,
    resource_owner: str = None,
    caller_arn: str = None,
    context_entries: List = None,
    resource_handling_option: str = None,
    max_items: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Simulate how a set of IAM policies attached to an IAM entity works with a list of API operations and Amazon Web Services resources to determine the policies' effective permissions. The entity can be an IAM user, group, or role. If you specify a user, then the simulation also includes all of the policies that are attached to groups that the user belongs to. You can simulate resources that don't exist in your account. You can optionally include a list of one or more additional policies specified as strings to include in the simulation. If you want to simulate only policies specified as strings, use SimulateCustomPolicy instead. You can also optionally include one resource-based policy to be evaluated with each of the resources included in the simulation. The simulation does not perform the API operations; it only checks the authorization to determine if the simulated policies allow or deny the operations.  Note: This operation discloses information about the permissions granted to other users. If you do not want users to see other user's permissions, then consider allowing them to use SimulateCustomPolicy instead. Context keys are variables maintained by Amazon Web Services and its services that provide details about the context of an API query request. You can use the Condition element of an IAM policy to evaluate context keys. To get the list of context keys that the policies require for correct simulation, use GetContextKeysForPrincipalPolicy. If the output is long, you can use the MaxItems and Marker parameters to paginate the results. For more information about using the policy simulator, see Testing IAM policies with the IAM policy simulator in the IAM User Guide.

    Args:
        policy_source_arn(str): The Amazon Resource Name (ARN) of a user, group, or role whose policies you want to include in the simulation. If you specify a user, group, or role, the simulation includes all policies that are associated with that entity. If you specify a user, the simulation also includes all policies that are attached to any groups the user belongs to. The maximum length of the policy document that you can pass in this operation, including whitespace, is listed below. To view the maximum character counts of a managed policy with no whitespaces, see IAM and STS character quotas. For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.
        policy_input_list(List, optional): An optional list of additional policy documents to include in the simulation. Each document is specified as a string containing the complete, valid JSON text of an IAM policy. The regex pattern used to validate this parameter is a string of characters consisting of the following:   Any printable ASCII character ranging from the space character (\u0020) through the end of the ASCII character range   The printable characters in the Basic Latin and Latin-1 Supplement character set (through \u00FF)   The special characters tab (\u0009), line feed (\u000A), and carriage return (\u000D)  . Defaults to None.
        permissions_boundary_policy_input_list(List, optional): The IAM permissions boundary policy to simulate. The permissions boundary sets the maximum permissions that the entity can have. You can input only one permissions boundary when you pass a policy to this operation. An IAM entity can only have one permissions boundary in effect at a time. For example, if a permissions boundary is attached to an entity and you pass in a different permissions boundary policy using this parameter, then the new permissions boundary policy is used for the simulation. For more information about permissions boundaries, see Permissions boundaries for IAM entities in the IAM User Guide. The policy input is specified as a string containing the complete, valid JSON text of a permissions boundary policy. The maximum length of the policy document that you can pass in this operation, including whitespace, is listed below. To view the maximum character counts of a managed policy with no whitespaces, see IAM and STS character quotas. The regex pattern used to validate this parameter is a string of characters consisting of the following:   Any printable ASCII character ranging from the space character (\u0020) through the end of the ASCII character range   The printable characters in the Basic Latin and Latin-1 Supplement character set (through \u00FF)   The special characters tab (\u0009), line feed (\u000A), and carriage return (\u000D)  . Defaults to None.
        action_names(List): A list of names of API operations to evaluate in the simulation. Each operation is evaluated for each resource. Each operation must include the service identifier, such as iam:CreateUser.
        resource_arns(List, optional): A list of ARNs of Amazon Web Services resources to include in the simulation. If this parameter is not provided, then the value defaults to * (all resources). Each API in the ActionNames parameter is evaluated for each resource in this list. The simulation determines the access result (allowed or denied) of each combination and reports it in the response. You can simulate resources that don't exist in your account. The simulation does not automatically retrieve policies for the specified resources. If you want to include a resource policy in the simulation, then you must include the policy as a string in the ResourcePolicy parameter. For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference. Defaults to None.
        resource_policy(str, optional): A resource-based policy to include in the simulation provided as a string. Each resource in the simulation is treated as if it had this policy attached. You can include only one resource-based policy in a simulation. The maximum length of the policy document that you can pass in this operation, including whitespace, is listed below. To view the maximum character counts of a managed policy with no whitespaces, see IAM and STS character quotas. The regex pattern used to validate this parameter is a string of characters consisting of the following:   Any printable ASCII character ranging from the space character (\u0020) through the end of the ASCII character range   The printable characters in the Basic Latin and Latin-1 Supplement character set (through \u00FF)   The special characters tab (\u0009), line feed (\u000A), and carriage return (\u000D)  . Defaults to None.
        resource_owner(str, optional): An account ID that specifies the owner of any simulated resource that does not identify its owner in the resource ARN. Examples of resource ARNs include an S3 bucket or object. If ResourceOwner is specified, it is also used as the account owner of any ResourcePolicy included in the simulation. If the ResourceOwner parameter is not specified, then the owner of the resources and the resource policy defaults to the account of the identity provided in CallerArn. This parameter is required only if you specify a resource-based policy and account that owns the resource is different from the account that owns the simulated calling user CallerArn. Defaults to None.
        caller_arn(str, optional): The ARN of the IAM user that you want to specify as the simulated caller of the API operations. If you do not specify a CallerArn, it defaults to the ARN of the user that you specify in PolicySourceArn, if you specified a user. If you include both a PolicySourceArn (for example, arn:aws:iam::123456789012:user/David) and a CallerArn (for example, arn:aws:iam::123456789012:user/Bob), the result is that you simulate calling the API operations as Bob, as if Bob had David's policies. You can specify only the ARN of an IAM user. You cannot specify the ARN of an assumed role, federated user, or a service principal.  CallerArn is required if you include a ResourcePolicy and the PolicySourceArn is not the ARN for an IAM user. This is required so that the resource-based policy's Principal element has a value to use in evaluating the policy. For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference. Defaults to None.
        context_entries(List, optional): A list of context keys and corresponding values for the simulation to use. Whenever a context key is evaluated in one of the simulated IAM permissions policies, the corresponding value is supplied. Defaults to None.
        resource_handling_option(str, optional): Specifies the type of simulation to run. Different API operations that support resource-based policies require different combinations of resources. By specifying the type of simulation to run, you enable the policy simulator to enforce the presence of the required resources to ensure reliable simulation results. If your simulation does not match one of the following scenarios, then you can omit this parameter. The following list shows each of the supported scenario values and the resources that you must define to run the simulation. Each of the EC2 scenarios requires that you specify instance, image, and security group resources. If your scenario includes an EBS volume, then you must specify that volume as a resource. If the EC2 scenario includes VPC, then you must supply the network interface resource. If it includes an IP subnet, then you must specify the subnet resource. For more information on the EC2 scenario options, see Supported platforms in the Amazon EC2 User Guide.    EC2-Classic-InstanceStore  instance, image, security group    EC2-Classic-EBS  instance, image, security group, volume    EC2-VPC-InstanceStore  instance, image, security group, network interface    EC2-VPC-InstanceStore-Subnet  instance, image, security group, network interface, subnet    EC2-VPC-EBS  instance, image, security group, network interface, volume    EC2-VPC-EBS-Subnet  instance, image, security group, network interface, subnet, volume  . Defaults to None.
        max_items(int, optional): Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the IsTruncated response element is true. If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the IsTruncated response element returns true, and Marker contains a value to include in the subsequent call that tells the service where to continue from. Defaults to None.
        marker(str, optional): Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker element in the response that you received to indicate where the next call should start. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.principal_policy.simulate(
                ctx, policy_source_arn=value, action_names=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.principal_policy.simulate policy_source_arn=value, action_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="simulate_principal_policy",
        op_kwargs={
            "PolicySourceArn": policy_source_arn,
            "PolicyInputList": policy_input_list,
            "PermissionsBoundaryPolicyInputList": permissions_boundary_policy_input_list,
            "ActionNames": action_names,
            "ResourceArns": resource_arns,
            "ResourcePolicy": resource_policy,
            "ResourceOwner": resource_owner,
            "CallerArn": caller_arn,
            "ContextEntries": context_entries,
            "ResourceHandlingOption": resource_handling_option,
            "MaxItems": max_items,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, configuration_aggregator_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified configuration aggregator and the aggregated data associated with the aggregator.

    Args:
        configuration_aggregator_name(str): The name of the configuration aggregator.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.configuration.aggregator.init.delete(
                ctx, configuration_aggregator_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.configuration.aggregator.init.delete configuration_aggregator_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="delete_configuration_aggregator",
        op_kwargs={"ConfigurationAggregatorName": configuration_aggregator_name},
    )


async def describe_all(
    hub,
    ctx,
    configuration_aggregator_names: List = None,
    next_token: str = None,
    limit: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the details of one or more configuration aggregators. If the configuration aggregator is not specified, this action returns the details for all the configuration aggregators associated with the account.

    Args:
        configuration_aggregator_names(List, optional): The name of the configuration aggregators. Defaults to None.
        next_token(str, optional): The nextToken string returned on a previous page that you use to get the next page of results in a paginated response. Defaults to None.
        limit(int, optional): The maximum number of configuration aggregators returned on each page. The default is maximum. If you specify 0, AWS Config uses the default. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.configuration.aggregator.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.configuration.aggregator.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="describe_configuration_aggregators",
        op_kwargs={
            "ConfigurationAggregatorNames": configuration_aggregator_names,
            "NextToken": next_token,
            "Limit": limit,
        },
    )


async def put(
    hub,
    ctx,
    configuration_aggregator_name: str,
    account_aggregation_sources: List = None,
    organization_aggregation_source: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates and updates the configuration aggregator with the selected source accounts and regions. The source account can be individual account(s) or an organization.  accountIds that are passed will be replaced with existing accounts. If you want to add additional accounts into the aggregator, call DescribeAggregator to get the previous accounts and then append new ones.  AWS Config should be enabled in source accounts and regions you want to aggregate. If your source type is an organization, you must be signed in to the management account or a registered delegated administrator and all the features must be enabled in your organization. If the caller is a management account, AWS Config calls EnableAwsServiceAccess API to enable integration between AWS Config and AWS Organizations. If the caller is a registered delegated administrator, AWS Config calls ListDelegatedAdministrators API to verify whether the caller is a valid delegated administrator. To register a delegated administrator, see Register a Delegated Administrator in the AWS Config developer guide.

    Args:
        configuration_aggregator_name(str): The name of the configuration aggregator.
        account_aggregation_sources(List, optional): A list of AccountAggregationSource object. . Defaults to None.
        organization_aggregation_source(Dict, optional): An OrganizationAggregationSource object. Defaults to None.
        tags(List, optional): An array of tag object. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.configuration.aggregator.init.put(
                ctx, configuration_aggregator_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.configuration.aggregator.init.put configuration_aggregator_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="put_configuration_aggregator",
        op_kwargs={
            "ConfigurationAggregatorName": configuration_aggregator_name,
            "AccountAggregationSources": account_aggregation_sources,
            "OrganizationAggregationSource": organization_aggregation_source,
            "Tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, fleet_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the identity provider configuration of the specified fleet.

    Args:
        fleet_arn(str): The ARN of the fleet.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.identity_provider_configuration.describe(
                ctx, fleet_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.identity_provider_configuration.describe fleet_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="describe_identity_provider_configuration",
        op_kwargs={"FleetArn": fleet_arn},
    )


async def update(
    hub,
    ctx,
    fleet_arn: str,
    identity_provider_type: str,
    identity_provider_saml_metadata: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the identity provider configuration for the fleet.

    Args:
        fleet_arn(str): The ARN of the fleet.
        identity_provider_type(str): The type of identity provider.
        identity_provider_saml_metadata(str, optional): The SAML metadata document provided by the customer’s identity provider. The existing IdentityProviderSamlMetadata is unset if null is passed. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.identity_provider_configuration.update(
                ctx, fleet_arn=value, identity_provider_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.identity_provider_configuration.update fleet_arn=value, identity_provider_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="update_identity_provider_configuration",
        op_kwargs={
            "FleetArn": fleet_arn,
            "IdentityProviderType": identity_provider_type,
            "IdentityProviderSamlMetadata": identity_provider_saml_metadata,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the Resolver rule policy for a specified rule. A Resolver rule policy includes the rule that you want to share with another account, the account that you want to share the rule with, and the Resolver operations that you want to allow the account to use.

    Args:
        arn(str): The ID of the Resolver rule that you want to get the Resolver rule policy for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.rule.policy.get(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.rule.policy.get arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="get_resolver_rule_policy",
        op_kwargs={"Arn": arn},
    )


async def put(hub, ctx, arn: str, resolver_rule_policy: str) -> Dict:
    r"""
    **Autogenerated function**

    Specifies an AWS rule that you want to share with another account, the account that you want to share the rule with, and the operations that you want the account to be able to perform on the rule.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the rule that you want to share with another account.
        resolver_rule_policy(str): An AWS Identity and Access Management policy statement that lists the rules that you want to share with another AWS account and the operations that you want the account to be able to perform. You can specify the following operations in the Action section of the statement:    route53resolver:GetResolverRule     route53resolver:AssociateResolverRule     route53resolver:DisassociateResolverRule     route53resolver:ListResolverRules     route53resolver:ListResolverRuleAssociations    In the Resource section of the statement, specify the ARN for the rule that you want to share with another account. Specify the same ARN that you specified in Arn.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.rule.policy.put(
                ctx, arn=value, resolver_rule_policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.rule.policy.put arn=value, resolver_rule_policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="put_resolver_rule_policy",
        op_kwargs={"Arn": arn, "ResolverRulePolicy": resolver_rule_policy},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, user_pool_id: str, identifier: str, name: str, scopes: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new OAuth2.0 resource server and defines custom scopes in it.

    Args:
        user_pool_id(str): The user pool ID for the user pool.
        identifier(str): A unique resource server identifier for the resource server. This could be an HTTPS endpoint where the resource server is located. For example, https://my-weather-api.example.com.
        name(str): A friendly name for the resource server.
        scopes(List, optional): A list of scopes. Each scope is map, where the keys are name and description. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.resource.server.create(
                ctx, user_pool_id=value, identifier=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.resource.server.create user_pool_id=value, identifier=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="create_resource_server",
        op_kwargs={
            "UserPoolId": user_pool_id,
            "Identifier": identifier,
            "Name": name,
            "Scopes": scopes,
        },
    )


async def delete(hub, ctx, user_pool_id: str, identifier: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a resource server.

    Args:
        user_pool_id(str): The user pool ID for the user pool that hosts the resource server.
        identifier(str): The identifier for the resource server.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.resource.server.delete(
                ctx, user_pool_id=value, identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.resource.server.delete user_pool_id=value, identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="delete_resource_server",
        op_kwargs={"UserPoolId": user_pool_id, "Identifier": identifier},
    )


async def describe(hub, ctx, user_pool_id: str, identifier: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a resource server.

    Args:
        user_pool_id(str): The user pool ID for the user pool that hosts the resource server.
        identifier(str): The identifier for the resource server.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.resource.server.describe(
                ctx, user_pool_id=value, identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.resource.server.describe user_pool_id=value, identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="describe_resource_server",
        op_kwargs={"UserPoolId": user_pool_id, "Identifier": identifier},
    )


async def list_all(
    hub, ctx, user_pool_id: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the resource servers for a user pool.

    Args:
        user_pool_id(str): The user pool ID for the user pool.
        max_results(int, optional): The maximum number of resource servers to return. Defaults to None.
        next_token(str, optional): A pagination token. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.resource.server.list_all(ctx, user_pool_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.resource.server.list_all user_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="list_resource_servers",
        op_kwargs={
            "UserPoolId": user_pool_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub, ctx, user_pool_id: str, identifier: str, name: str, scopes: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the name and scopes of resource server. All other fields are read-only.  If you don't provide a value for an attribute, it will be set to the default value.

    Args:
        user_pool_id(str): The user pool ID for the user pool.
        identifier(str): The identifier for the resource server.
        name(str): The name of the resource server.
        scopes(List, optional): The scope values to be set for the resource server. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.resource.server.update(
                ctx, user_pool_id=value, identifier=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.resource.server.update user_pool_id=value, identifier=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="update_resource_server",
        op_kwargs={
            "UserPoolId": user_pool_id,
            "Identifier": identifier,
            "Name": name,
            "Scopes": scopes,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(
    hub, ctx, registry_name: str, schema_name: str, schema_version: str
) -> None:
    r"""
    **Autogenerated function**

    Delete the schema version definition

    Args:
        registry_name(str): The name of the registry.
        schema_name(str): The name of the schema.
        schema_version(str): The version number of the schema.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.schemas.schema.version.delete(
                ctx, registry_name=value, schema_name=value, schema_version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.schemas.schema.version.delete registry_name=value, schema_name=value, schema_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="schemas",
        operation="delete_schema_version",
        op_kwargs={
            "RegistryName": registry_name,
            "SchemaName": schema_name,
            "SchemaVersion": schema_version,
        },
    )


async def list_all(
    hub,
    ctx,
    registry_name: str,
    schema_name: str,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Provides a list of the schema versions and related information.

    Args:
        limit(int, optional): . Defaults to None.
        next_token(str, optional): The token that specifies the next page of results to return. To request the first page, leave NextToken empty. The token will expire in 24 hours, and cannot be shared with other accounts. Defaults to None.
        registry_name(str): The name of the registry.
        schema_name(str): The name of the schema.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.schemas.schema.version.list_all(
                ctx, registry_name=value, schema_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.schemas.schema.version.list_all registry_name=value, schema_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="schemas",
        operation="list_schema_versions",
        op_kwargs={
            "Limit": limit,
            "NextToken": next_token,
            "RegistryName": registry_name,
            "SchemaName": schema_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "type"


async def get(hub, ctx, category: str, owner: str, provider: str, version: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about an action type created for an external provider, where the action is to be used by customers of the external provider. The action can be created with any supported integration model.

    Args:
        category(str): Defines what kind of action can be taken in the stage. The following are the valid values:    Source     Build     Test     Deploy     Approval     Invoke   .
        owner(str): The creator of an action type that was created with any supported integration model. There are two valid values: AWS and ThirdParty.
        provider(str): The provider of the action type being called. The provider name is specified when the action type is created.
        version(str): A string that describes the action type version.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.action.type_.get(
                ctx, category=value, owner=value, provider=value, version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.action.type.get category=value, owner=value, provider=value, version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="get_action_type",
        op_kwargs={
            "category": category,
            "owner": owner,
            "provider": provider,
            "version": version,
        },
    )


async def list_all(
    hub,
    ctx,
    action_owner_filter: str = None,
    next_token: str = None,
    region_filter: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a summary of all AWS CodePipeline action types associated with your account.

    Args:
        action_owner_filter(str, optional): Filters the list of action types to those created by a specified entity. Defaults to None.
        next_token(str, optional): An identifier that was returned from the previous list action types call, which can be used to return the next set of action types in the list. Defaults to None.
        region_filter(str, optional): The Region to filter on for the list of action types. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.action.type_.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.action.type.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="list_action_types",
        op_kwargs={
            "actionOwnerFilter": action_owner_filter,
            "nextToken": next_token,
            "regionFilter": region_filter,
        },
    )


async def update(hub, ctx, action_type: Dict) -> None:
    r"""
    **Autogenerated function**

    Updates an action type that was created with any supported integration model, where the action type is to be used by customers of the action type provider. Use a JSON file with the action definition and UpdateActionType to provide the full structure.

    Args:
        action_type(Dict): The action type definition for the action type to be updated.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.action.type_.update(ctx, action_type=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.action.type.update action_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="update_action_type",
        op_kwargs={"actionType": action_type},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    amzn_client_token: str = None,
    initial_version: Dict = None,
    name: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a core definition. You may provide the initial version of the core definition now or use ''CreateCoreDefinitionVersion'' at a later time. Greengrass groups must each contain exactly one Greengrass core.

    Args:
        amzn_client_token(str, optional): A client token used to correlate requests and responses. Defaults to None.
        initial_version(Dict, optional): Information about the initial version of the core definition. Defaults to None.
        name(str, optional): The name of the core definition. Defaults to None.
        tags(Dict, optional): Tag(s) to add to the new resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.core_definition.init.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.core_definition.init.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="create_core_definition",
        op_kwargs={
            "AmznClientToken": amzn_client_token,
            "InitialVersion": initial_version,
            "Name": name,
            "tags": tags,
        },
    )


async def delete(hub, ctx, core_definition_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a core definition.

    Args:
        core_definition_id(str): The ID of the core definition.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.core_definition.init.delete(
                ctx, core_definition_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.core_definition.init.delete core_definition_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="delete_core_definition",
        op_kwargs={"CoreDefinitionId": core_definition_id},
    )


async def get(hub, ctx, core_definition_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a core definition version.

    Args:
        core_definition_id(str): The ID of the core definition.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.core_definition.init.get(
                ctx, core_definition_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.core_definition.init.get core_definition_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="get_core_definition",
        op_kwargs={"CoreDefinitionId": core_definition_id},
    )


async def list_all(hub, ctx, max_results: str = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of core definitions.

    Args:
        max_results(str, optional): The maximum number of results to be returned per request. Defaults to None.
        next_token(str, optional): The token for the next set of results, or ''null'' if there are no additional results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.core_definition.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.core_definition.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="list_core_definitions",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(hub, ctx, core_definition_id: str, name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates a core definition.

    Args:
        core_definition_id(str): The ID of the core definition.
        name(str, optional): The name of the definition. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.core_definition.init.update(
                ctx, core_definition_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.core_definition.init.update core_definition_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="update_core_definition",
        op_kwargs={"CoreDefinitionId": core_definition_id, "Name": name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub, ctx, environment_id: str, duration_in_minutes: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Request programmatic credentials to use with Habanero SDK.

    Args:
        duration_in_minutes(int, optional): The time duration in which the credentials remain valid. . Defaults to None.
        environment_id(str): The habanero environment identifier.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.finspace_data.programmatic_access_credential.get_all(
                ctx, environment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.finspace_data.programmatic_access_credential.get_all environment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="finspace-data",
        operation="get_programmatic_access_credentials",
        op_kwargs={
            "durationInMinutes": duration_in_minutes,
            "environmentId": environment_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    schedule_definitions: List = None,
    schedule_identifier: str = None,
    schedule_description: str = None,
    tags: List = None,
    dry_run: bool = None,
    next_invocations: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create a snapshot schedule that can be associated to a cluster and which overrides the default system backup schedule.

    Args:
        schedule_definitions(List, optional): The definition of the snapshot schedule. The definition is made up of schedule expressions, for example "cron(30 12 *)" or "rate(12 hours)". . Defaults to None.
        schedule_identifier(str, optional): A unique identifier for a snapshot schedule. Only alphanumeric characters are allowed for the identifier. Defaults to None.
        schedule_description(str, optional): The description of the snapshot schedule. Defaults to None.
        tags(List, optional): An optional set of tags you can use to search for the schedule. Defaults to None.
        dry_run(bool, optional): . Defaults to None.
        next_invocations(int, optional): . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.snapshot.schedule.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.snapshot.schedule.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="create_snapshot_schedule",
        op_kwargs={
            "ScheduleDefinitions": schedule_definitions,
            "ScheduleIdentifier": schedule_identifier,
            "ScheduleDescription": schedule_description,
            "Tags": tags,
            "DryRun": dry_run,
            "NextInvocations": next_invocations,
        },
    )


async def delete(hub, ctx, schedule_identifier: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a snapshot schedule.

    Args:
        schedule_identifier(str): A unique identifier of the snapshot schedule to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.snapshot.schedule.delete(
                ctx, schedule_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.snapshot.schedule.delete schedule_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="delete_snapshot_schedule",
        op_kwargs={"ScheduleIdentifier": schedule_identifier},
    )


async def describe_all(
    hub,
    ctx,
    cluster_identifier: str = None,
    schedule_identifier: str = None,
    tag_keys: List = None,
    tag_values: List = None,
    marker: str = None,
    max_records: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of snapshot schedules.

    Args:
        cluster_identifier(str, optional): The unique identifier for the cluster whose snapshot schedules you want to view. Defaults to None.
        schedule_identifier(str, optional): A unique identifier for a snapshot schedule. Defaults to None.
        tag_keys(List, optional): The key value for a snapshot schedule tag. Defaults to None.
        tag_values(List, optional): The value corresponding to the key of the snapshot schedule tag. Defaults to None.
        marker(str, optional): A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned marker value in the marker parameter and retrying the command. If the marker field is empty, all response records have been retrieved for the request. Defaults to None.
        max_records(int, optional): The maximum number or response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.snapshot.schedule.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.snapshot.schedule.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_snapshot_schedules",
        op_kwargs={
            "ClusterIdentifier": cluster_identifier,
            "ScheduleIdentifier": schedule_identifier,
            "TagKeys": tag_keys,
            "TagValues": tag_values,
            "Marker": marker,
            "MaxRecords": max_records,
        },
    )


async def modify(
    hub, ctx, schedule_identifier: str, schedule_definitions: List
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies a snapshot schedule. Any schedule associated with a cluster is modified asynchronously.

    Args:
        schedule_identifier(str): A unique alphanumeric identifier of the schedule to modify.
        schedule_definitions(List): An updated list of schedule definitions. A schedule definition is made up of schedule expressions, for example, "cron(30 12 *)" or "rate(12 hours)".

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.snapshot.schedule.modify(
                ctx, schedule_identifier=value, schedule_definitions=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.snapshot.schedule.modify schedule_identifier=value, schedule_definitions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="modify_snapshot_schedule",
        op_kwargs={
            "ScheduleIdentifier": schedule_identifier,
            "ScheduleDefinitions": schedule_definitions,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def notify(hub, ctx, subject: str, message_text: str, worker_ids: List) -> Dict:
    r"""
    **Autogenerated function**

     The NotifyWorkers operation sends an email to one or more Workers that you specify with the Worker ID. You can specify up to 100 Worker IDs to send the same message with a single call to the NotifyWorkers operation. The NotifyWorkers operation will send a notification email to a Worker only if you have previously approved or rejected work from the Worker.

    Args:
        subject(str): The subject line of the email message to send. Can include up to 200 characters.
        message_text(str): The text of the email message to send. Can include up to 4,096 characters.
        worker_ids(List): A list of Worker IDs you wish to notify. You can notify upto 100 Workers at a time.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.worker.init.notify(
                ctx, subject=value, message_text=value, worker_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.worker.init.notify subject=value, message_text=value, worker_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="notify_workers",
        op_kwargs={
            "Subject": subject,
            "MessageText": message_text,
            "WorkerIds": worker_ids,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    access_token: str,
    account_id: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all roles that are assigned to the user for a given AWS account.

    Args:
        next_token(str, optional): The page token from the previous response output when you request subsequent pages. Defaults to None.
        max_results(int, optional): The number of items that clients can request per page. Defaults to None.
        access_token(str): The token issued by the CreateToken API call. For more information, see CreateToken in the AWS SSO OIDC API Reference Guide.
        account_id(str): The identifier for the AWS account that is assigned to the user.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso.account.role.list_all(
                ctx, access_token=value, account_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso.account.role.list_all access_token=value, account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso",
        operation="list_account_roles",
        op_kwargs={
            "nextToken": next_token,
            "maxResults": max_results,
            "accessToken": access_token,
            "accountId": account_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, application_id: str, environment_id: str, deployment_number: int
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve information about a configuration deployment.

    Args:
        application_id(str): The ID of the application that includes the deployment you want to get. .
        environment_id(str): The ID of the environment that includes the deployment you want to get. .
        deployment_number(int): The sequence number of the deployment.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appconfig.deployment.init.get(
                ctx, application_id=value, environment_id=value, deployment_number=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appconfig.deployment.init.get application_id=value, environment_id=value, deployment_number=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appconfig",
        operation="get_deployment",
        op_kwargs={
            "ApplicationId": application_id,
            "EnvironmentId": environment_id,
            "DeploymentNumber": deployment_number,
        },
    )


async def list_all(
    hub,
    ctx,
    application_id: str,
    environment_id: str,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the deployments for an environment.

    Args:
        application_id(str): The application ID.
        environment_id(str): The environment ID.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): A token to start the list. Use this token to get the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appconfig.deployment.init.list_all(
                ctx, application_id=value, environment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appconfig.deployment.init.list_all application_id=value, environment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appconfig",
        operation="list_deployments",
        op_kwargs={
            "ApplicationId": application_id,
            "EnvironmentId": environment_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def start(
    hub,
    ctx,
    application_id: str,
    environment_id: str,
    deployment_strategy_id: str,
    configuration_profile_id: str,
    configuration_version: str,
    description: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts a deployment.

    Args:
        application_id(str): The application ID.
        environment_id(str): The environment ID.
        deployment_strategy_id(str): The deployment strategy ID.
        configuration_profile_id(str): The configuration profile ID.
        configuration_version(str): The configuration version to deploy.
        description(str, optional): A description of the deployment. Defaults to None.
        tags(Dict, optional): Metadata to assign to the deployment. Tags help organize and categorize your AppConfig resources. Each tag consists of a key and an optional value, both of which you define. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appconfig.deployment.init.start(
                ctx,
                application_id=value,
                environment_id=value,
                deployment_strategy_id=value,
                configuration_profile_id=value,
                configuration_version=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appconfig.deployment.init.start application_id=value, environment_id=value, deployment_strategy_id=value, configuration_profile_id=value, configuration_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appconfig",
        operation="start_deployment",
        op_kwargs={
            "ApplicationId": application_id,
            "EnvironmentId": environment_id,
            "DeploymentStrategyId": deployment_strategy_id,
            "ConfigurationProfileId": configuration_profile_id,
            "ConfigurationVersion": configuration_version,
            "Description": description,
            "Tags": tags,
        },
    )


async def stop(
    hub, ctx, application_id: str, environment_id: str, deployment_number: int
) -> Dict:
    r"""
    **Autogenerated function**

    Stops a deployment. This API action works only on deployments that have a status of DEPLOYING. This action moves the deployment to a status of ROLLED_BACK.

    Args:
        application_id(str): The application ID.
        environment_id(str): The environment ID.
        deployment_number(int): The sequence number of the deployment.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appconfig.deployment.init.stop(
                ctx, application_id=value, environment_id=value, deployment_number=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appconfig.deployment.init.stop application_id=value, environment_id=value, deployment_number=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appconfig",
        operation="stop_deployment",
        op_kwargs={
            "ApplicationId": application_id,
            "EnvironmentId": environment_id,
            "DeploymentNumber": deployment_number,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def put(hub, ctx, ip: str, destination_pool_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Move a dedicated IP address to an existing dedicated IP pool.  The dedicated IP address that you specify must already exist, and must be associated with your AWS account.  The dedicated IP pool you specify must already exist. You can create a new pool by using the CreateDedicatedIpPool operation.

    Args:
        ip(str): The IP address that you want to move to the dedicated IP pool. The value you specify has to be a dedicated IP address that's associated with your AWS account.
        destination_pool_name(str): The name of the IP pool that you want to add the dedicated IP address to. You have to specify an IP pool that already exists.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.dedicated_ip.in_pool.put(
                ctx, ip=value, destination_pool_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.dedicated_ip.in_pool.put ip=value, destination_pool_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="put_dedicated_ip_in_pool",
        op_kwargs={"Ip": ip, "DestinationPoolName": destination_pool_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def deregister(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

     Deregisters an account in Audit Manager.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.account.init.deregister(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.account.init.deregister
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="auditmanager", operation="deregister_account", op_kwargs={}
    )


async def register(
    hub, ctx, kms_key: str = None, delegated_admin_account: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     Enables Audit Manager for the specified account.

    Args:
        kms_key(str, optional):  The KMS key details. . Defaults to None.
        delegated_admin_account(str, optional):  The delegated administrator account for Audit Manager. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.account.init.register(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.account.init.register
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="register_account",
        op_kwargs={"kmsKey": kms_key, "delegatedAdminAccount": delegated_admin_account},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(
    hub,
    ctx,
    domain: str,
    repository: str,
    domain_owner: str = None,
    policy_revision: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Deletes the resource policy that is set on a repository. After a resource policy is deleted, the permissions allowed and denied by the deleted policy are removed. The effect of deleting a resource policy might not be immediate.    Use DeleteRepositoryPermissionsPolicy with caution. After a policy is deleted, AWS users, roles, and accounts lose permissions to perform the repository actions granted by the deleted policy.

    Args:
        domain(str):  The name of the domain that contains the repository associated with the resource policy to be deleted. .
        domain_owner(str, optional):  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. . Defaults to None.
        repository(str):  The name of the repository that is associated with the resource policy to be deleted .
        policy_revision(str, optional):  The revision of the repository's resource policy to be deleted. This revision is used for optimistic locking, which prevents others from accidentally overwriting your changes to the repository's resource policy. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeartifact.repository.permission_policy.delete(
                ctx, domain=value, repository=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeartifact.repository.permission_policy.delete domain=value, repository=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeartifact",
        operation="delete_repository_permissions_policy",
        op_kwargs={
            "domain": domain,
            "domainOwner": domain_owner,
            "repository": repository,
            "policyRevision": policy_revision,
        },
    )


async def get(hub, ctx, domain: str, repository: str, domain_owner: str = None) -> Dict:
    r"""
    **Autogenerated function**

     Returns the resource policy that is set on a repository.

    Args:
        domain(str):  The name of the domain containing the repository whose associated resource policy is to be retrieved. .
        domain_owner(str, optional):  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. . Defaults to None.
        repository(str):  The name of the repository whose associated resource policy is to be retrieved. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeartifact.repository.permission_policy.get(
                ctx, domain=value, repository=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeartifact.repository.permission_policy.get domain=value, repository=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeartifact",
        operation="get_repository_permissions_policy",
        op_kwargs={
            "domain": domain,
            "domainOwner": domain_owner,
            "repository": repository,
        },
    )


async def put(
    hub,
    ctx,
    domain: str,
    repository: str,
    policy_document: str,
    domain_owner: str = None,
    policy_revision: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Sets the resource policy on a repository that specifies permissions to access it.   When you call PutRepositoryPermissionsPolicy, the resource policy on the repository is ignored when evaluting permissions. This ensures that the owner of a repository cannot lock themselves out of the repository, which would prevent them from being able to update the resource policy.

    Args:
        domain(str):  The name of the domain containing the repository to set the resource policy on. .
        domain_owner(str, optional):  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. . Defaults to None.
        repository(str):  The name of the repository to set the resource policy on. .
        policy_revision(str, optional):  Sets the revision of the resource policy that specifies permissions to access the repository. This revision is used for optimistic locking, which prevents others from overwriting your changes to the repository's resource policy. . Defaults to None.
        policy_document(str):  A valid displayable JSON Aspen policy string to be set as the access control resource policy on the provided repository. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeartifact.repository.permission_policy.put(
                ctx, domain=value, repository=value, policy_document=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeartifact.repository.permission_policy.put domain=value, repository=value, policy_document=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeartifact",
        operation="put_repository_permissions_policy",
        op_kwargs={
            "domain": domain,
            "domainOwner": domain_owner,
            "repository": repository,
            "policyRevision": policy_revision,
            "policyDocument": policy_document,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(hub, ctx, name: str, document_version: str) -> Dict:
    r"""
    **Autogenerated function**

    Set the default version of a document.

    Args:
        name(str): The name of a custom document that you want to set as the default version.
        document_version(str): The version of a custom document that you want to set as the default version.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.document.default_version.update(
                ctx, name=value, document_version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.document.default_version.update name=value, document_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="update_document_default_version",
        op_kwargs={"Name": name, "DocumentVersion": document_version},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    document_id: str,
    authentication_token: str = None,
    marker: str = None,
    limit: int = None,
    include: str = None,
    fields: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the document versions for the specified document. By default, only active versions are returned.

    Args:
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.
        document_id(str): The ID of the document.
        marker(str, optional): The marker for the next set of results. (You received this marker from a previous call.). Defaults to None.
        limit(int, optional): The maximum number of versions to return with this call. Defaults to None.
        include(str, optional): A comma-separated list of values. Specify "INITIALIZED" to include incomplete versions. Defaults to None.
        fields(str, optional): Specify "SOURCE" to include initialized versions and a URL for the source document. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.document.version.init.describe_all(
                ctx, document_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.document.version.init.describe_all document_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="describe_document_versions",
        op_kwargs={
            "AuthenticationToken": authentication_token,
            "DocumentId": document_id,
            "Marker": marker,
            "Limit": limit,
            "Include": include,
            "Fields": fields,
        },
    )


async def get(
    hub,
    ctx,
    document_id: str,
    version_id: str,
    authentication_token: str = None,
    fields: str = None,
    include_custom_metadata: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves version metadata for the specified document.

    Args:
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.
        document_id(str): The ID of the document.
        version_id(str): The version ID of the document.
        fields(str, optional): A comma-separated list of values. Specify "SOURCE" to include a URL for the source document. Defaults to None.
        include_custom_metadata(bool, optional): Set this to TRUE to include custom metadata in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.document.version.init.get(
                ctx, document_id=value, version_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.document.version.init.get document_id=value, version_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="get_document_version",
        op_kwargs={
            "AuthenticationToken": authentication_token,
            "DocumentId": document_id,
            "VersionId": version_id,
            "Fields": fields,
            "IncludeCustomMetadata": include_custom_metadata,
        },
    )


async def update(
    hub,
    ctx,
    document_id: str,
    version_id: str,
    authentication_token: str = None,
    version_status: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Changes the status of the document version to ACTIVE.  Amazon WorkDocs also sets its document container to ACTIVE. This is the last step in a document upload, after the client uploads the document to an S3-presigned URL returned by InitiateDocumentVersionUpload.

    Args:
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.
        document_id(str): The ID of the document.
        version_id(str): The version ID of the document.
        version_status(str, optional): The status of the version. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.document.version.init.update(
                ctx, document_id=value, version_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.document.version.init.update document_id=value, version_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="update_document_version",
        op_kwargs={
            "AuthenticationToken": authentication_token,
            "DocumentId": document_id,
            "VersionId": version_id,
            "VersionStatus": version_status,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub, ctx, service_code_list: List = None, language: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the current list of AWS services and a list of service categories for each service. You then use service names and categories in your CreateCase requests. Each AWS service has its own set of categories. The service codes and category codes correspond to the values that appear in the Service and Category lists on the AWS Support Center Create Case page. The values in those fields don't necessarily match the service codes and categories returned by the DescribeServices operation. Always use the service codes and categories that the DescribeServices operation returns, so that you have the most recent set of service and category codes.    You must have a Business or Enterprise Support plan to use the AWS Support API.    If you call the AWS Support API from an account that does not have a Business or Enterprise Support plan, the SubscriptionRequiredException error message appears. For information about changing your support plan, see AWS Support.

    Args:
        service_code_list(List, optional): A JSON-formatted list of service codes available for AWS services. Defaults to None.
        language(str, optional): The ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English ("en") and Japanese ("ja"). Language parameters must be passed explicitly for operations that take them. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.support.service.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.support.service.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="support",
        operation="describe_services",
        op_kwargs={"serviceCodeList": service_code_list, "language": language},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(hub, ctx, id_: str, version: int, comment: str) -> Dict:
    r"""
    **Autogenerated function**

    Updates the comment for a specified traffic policy version.

    Args:
        id_(str): The value of Id for the traffic policy that you want to update the comment for.
        version(int): The value of Version for the traffic policy that you want to update the comment for.
        comment(str): The new comment for the specified traffic policy and version.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.traffic_policy.comment.update(
                ctx, id_=value, version=value, comment=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.traffic_policy.comment.update id_=value, version=value, comment=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="update_traffic_policy_comment",
        op_kwargs={"Id": id_, "Version": version, "Comment": comment},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, name: str, metric_name: str, change_token: str, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Creates a Rule, which contains the IPSet objects, ByteMatchSet objects, and other predicates that identify the requests that you want to block. If you add more than one predicate to a Rule, a request must match all of the specifications to be allowed or blocked. For example, suppose that you add the following to a Rule:   An IPSet that matches the IP address 192.0.2.44/32    A ByteMatchSet that matches BadBot in the User-Agent header   You then add the Rule to a WebACL and specify that you want to blocks requests that satisfy the Rule. For a request to be blocked, it must come from the IP address 192.0.2.44 and the User-Agent header in the request must contain the value BadBot. To create and configure a Rule, perform the following steps:   Create and update the predicates that you want to include in the Rule. For more information, see CreateByteMatchSet, CreateIPSet, and CreateSqlInjectionMatchSet.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of a CreateRule request.   Submit a CreateRule request.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of an UpdateRule request.   Submit an UpdateRule request to specify the predicates that you want to include in the Rule.   Create and update a WebACL that contains the Rule. For more information, see CreateWebACL.   For more information about how to use the AWS WAF API to allow or block HTTP requests, see the AWS WAF Developer Guide.

    Args:
        name(str): A friendly name or description of the Rule. You can't change the name of a Rule after you create it.
        metric_name(str): A friendly name or description for the metrics for this Rule. The name can contain only alphanumeric characters (A-Z, a-z, 0-9), with maximum length 128 and minimum length one. It can't contain whitespace or metric names reserved for AWS WAF, including "All" and "Default_Action." You can't change the name of the metric after you create the Rule.
        change_token(str): The value returned by the most recent call to GetChangeToken.
        tags(List, optional): . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.rule.init.create(
                ctx, name=value, metric_name=value, change_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.rule.init.create name=value, metric_name=value, change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="create_rule",
        op_kwargs={
            "Name": name,
            "MetricName": metric_name,
            "ChangeToken": change_token,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, rule_id: str, change_token: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Permanently deletes a Rule. You can't delete a Rule if it's still used in any WebACL objects or if it still includes any predicates, such as ByteMatchSet objects. If you just want to remove a Rule from a WebACL, use UpdateWebACL. To permanently delete a Rule from AWS WAF, perform the following steps:   Update the Rule to remove predicates, if any. For more information, see UpdateRule.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of a DeleteRule request.   Submit a DeleteRule request.

    Args:
        rule_id(str): The RuleId of the Rule that you want to delete. RuleId is returned by CreateRule and by ListRules.
        change_token(str): The value returned by the most recent call to GetChangeToken.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.rule.init.delete(
                ctx, rule_id=value, change_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.rule.init.delete rule_id=value, change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="delete_rule",
        op_kwargs={"RuleId": rule_id, "ChangeToken": change_token},
    )


async def get(hub, ctx, rule_id: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns the Rule that is specified by the RuleId that you included in the GetRule request.

    Args:
        rule_id(str): The RuleId of the Rule that you want to get. RuleId is returned by CreateRule and by ListRules.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.rule.init.get(ctx, rule_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.rule.init.get rule_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="get_rule",
        op_kwargs={"RuleId": rule_id},
    )


async def list_all(hub, ctx, next_marker: str = None, limit: int = None) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns an array of RuleSummary objects.

    Args:
        next_marker(str, optional): If you specify a value for Limit and you have more Rules than the value of Limit, AWS WAF returns a NextMarker value in the response that allows you to list another group of Rules. For the second and subsequent ListRules requests, specify the value of NextMarker from the previous response to get information about another batch of Rules. Defaults to None.
        limit(int, optional): Specifies the number of Rules that you want AWS WAF to return for this request. If you have more Rules than the number that you specify for Limit, the response includes a NextMarker value that you can use to get another batch of Rules. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.rule.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.rule.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="list_rules",
        op_kwargs={"NextMarker": next_marker, "Limit": limit},
    )


async def update(hub, ctx, rule_id: str, change_token: str, updates: List) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Inserts or deletes Predicate objects in a Rule. Each Predicate object identifies a predicate, such as a ByteMatchSet or an IPSet, that specifies the web requests that you want to allow, block, or count. If you add more than one predicate to a Rule, a request must match all of the specifications to be allowed, blocked, or counted. For example, suppose that you add the following to a Rule:    A ByteMatchSet that matches the value BadBot in the User-Agent header   An IPSet that matches the IP address 192.0.2.44    You then add the Rule to a WebACL and specify that you want to block requests that satisfy the Rule. For a request to be blocked, the User-Agent header in the request must contain the value BadBot and the request must originate from the IP address 192.0.2.44. To create and configure a Rule, perform the following steps:   Create and update the predicates that you want to include in the Rule.   Create the Rule. See CreateRule.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of an UpdateRule request.   Submit an UpdateRule request to add predicates to the Rule.   Create and update a WebACL that contains the Rule. See CreateWebACL.   If you want to replace one ByteMatchSet or IPSet with another, you delete the existing one and add the new one. For more information about how to use the AWS WAF API to allow or block HTTP requests, see the AWS WAF Developer Guide.

    Args:
        rule_id(str): The RuleId of the Rule that you want to update. RuleId is returned by CreateRule and by ListRules.
        change_token(str): The value returned by the most recent call to GetChangeToken.
        updates(List): An array of RuleUpdate objects that you want to insert into or delete from a Rule. For more information, see the applicable data types:    RuleUpdate: Contains Action and Predicate     Predicate: Contains DataId, Negated, and Type     FieldToMatch: Contains Data and Type   .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.rule.init.update(
                ctx, rule_id=value, change_token=value, updates=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.rule.init.update rule_id=value, change_token=value, updates=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="update_rule",
        op_kwargs={"RuleId": rule_id, "ChangeToken": change_token, "Updates": updates},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(hub, ctx, gateway_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Lists the recovery points for a specified gateway. This operation is only supported in the cached volume gateway type. Each cache volume has one recovery point. A volume recovery point is a point in time at which all data of the volume is consistent and from which you can create a snapshot or clone a new cached volume from a source volume. To create a snapshot from a volume recovery point use the CreateSnapshotFromVolumeRecoveryPoint operation.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.volume.recovery_point.list_all(
                ctx, gateway_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.volume.recovery_point.list_all gateway_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="list_volume_recovery_points",
        op_kwargs={"GatewayARN": gateway_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub,
    ctx,
    product_code: str,
    filter_: Dict = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    GetEntitlements retrieves entitlement values for a given product. The results can be filtered based on customer identifier or product dimensions.

    Args:
        product_code(str): Product code is used to uniquely identify a product in AWS Marketplace. The product code will be provided by AWS Marketplace when the product listing is created.
        filter_(Dict, optional): Filter is used to return entitlements for a specific customer or for a specific dimension. Filters are described as keys mapped to a lists of values. Filtered requests are unioned for each value in the value list, and then intersected for each filter key. Defaults to None.
        next_token(str, optional): For paginated calls to GetEntitlements, pass the NextToken from the previous GetEntitlementsResult. Defaults to None.
        max_results(int, optional): The maximum number of items to retrieve from the GetEntitlements operation. For pagination, use the NextToken field in subsequent calls to GetEntitlements. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.marketplace_entitlement_entitlement.get_all(
                ctx, product_code=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.marketplace_entitlement_entitlement.get_all product_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="marketplace-entitlement",
        operation="get_entitlements",
        op_kwargs={
            "ProductCode": product_code,
            "Filter": filter_,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def admin(
    hub, ctx, user_pool_id: str, username: str, password: str, permanent: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Sets the specified user's password in a user pool as an administrator. Works on any user.  The password can be temporary or permanent. If it is temporary, the user status will be placed into the FORCE_CHANGE_PASSWORD state. When the user next tries to sign in, the InitiateAuth/AdminInitiateAuth response will contain the NEW_PASSWORD_REQUIRED challenge. If the user does not sign in before it expires, the user will not be able to sign in and their password will need to be reset by an administrator.  Once the user has set a new password, or the password is permanent, the user status will be set to Confirmed.

    Args:
        user_pool_id(str): The user pool ID for the user pool where you want to set the user's password.
        username(str): The user name of the user whose password you wish to set.
        password(str): The password for the user.
        permanent(bool, optional):  True if the password is permanent, False if it is temporary. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.set_user.password.admin(
                ctx, user_pool_id=value, username=value, password=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.set_user.password.admin user_pool_id=value, username=value, password=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="admin_set_user_password",
        op_kwargs={
            "UserPoolId": user_pool_id,
            "Username": username,
            "Password": password,
            "Permanent": permanent,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    repository_name: str,
    source_commit_specifier: str,
    destination_commit_specifier: str,
    merge_option: str,
    conflict_detail_level: str = None,
    conflict_resolution_strategy: str = None,
    author_name: str = None,
    email: str = None,
    commit_message: str = None,
    keep_empty_folders: bool = None,
    conflict_resolution: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an unreferenced commit that represents the result of merging two branches using a specified merge strategy. This can help you determine the outcome of a potential merge. This API cannot be used with the fast-forward merge strategy because that strategy does not create a merge commit.  This unreferenced merge commit can only be accessed using the GetCommit API or through git commands such as git fetch. To retrieve this commit, you must specify its commit ID or otherwise reference it.

    Args:
        repository_name(str): The name of the repository where you want to create the unreferenced merge commit.
        source_commit_specifier(str): The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
        destination_commit_specifier(str): The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
        merge_option(str): The merge option or strategy you want to use to merge the code.
        conflict_detail_level(str, optional): The level of conflict detail to use. If unspecified, the default FILE_LEVEL is used, which returns a not-mergeable result if the same file has differences in both branches. If LINE_LEVEL is specified, a conflict is considered not mergeable if the same file in both branches has differences on the same line. Defaults to None.
        conflict_resolution_strategy(str, optional): Specifies which branch to use when resolving conflicts, or whether to attempt automatically merging two versions of a file. The default is NONE, which requires any conflicts to be resolved manually before the merge operation is successful. Defaults to None.
        author_name(str, optional): The name of the author who created the unreferenced commit. This information is used as both the author and committer for the commit. Defaults to None.
        email(str, optional): The email address for the person who created the unreferenced commit. Defaults to None.
        commit_message(str, optional): The commit message for the unreferenced commit. Defaults to None.
        keep_empty_folders(bool, optional): If the commit contains deletions, whether to keep a folder or folder structure if the changes leave the folders empty. If this is specified as true, a .gitkeep file is created for empty folders. The default is false. Defaults to None.
        conflict_resolution(Dict, optional): If AUTOMERGE is the conflict resolution strategy, a list of inputs to use when resolving conflicts during a merge. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.unreferenced_merge_commit.create(
                ctx,
                repository_name=value,
                source_commit_specifier=value,
                destination_commit_specifier=value,
                merge_option=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.unreferenced_merge_commit.create repository_name=value, source_commit_specifier=value, destination_commit_specifier=value, merge_option=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="create_unreferenced_merge_commit",
        op_kwargs={
            "repositoryName": repository_name,
            "sourceCommitSpecifier": source_commit_specifier,
            "destinationCommitSpecifier": destination_commit_specifier,
            "mergeOption": merge_option,
            "conflictDetailLevel": conflict_detail_level,
            "conflictResolutionStrategy": conflict_resolution_strategy,
            "authorName": author_name,
            "email": email,
            "commitMessage": commit_message,
            "keepEmptyFolders": keep_empty_folders,
            "conflictResolution": conflict_resolution,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    forecast_export_job_name: str,
    forecast_arn: str,
    destination: Dict,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Exports a forecast created by the CreateForecast operation to your Amazon Simple Storage Service (Amazon S3) bucket. The forecast file name will match the following conventions: <ForecastExportJobName>_<ExportTimestamp>_<PartNumber> where the <ExportTimestamp> component is in Java SimpleDateFormat (yyyy-MM-ddTHH-mm-ssZ). You must specify a DataDestination object that includes an AWS Identity and Access Management (IAM) role that Amazon Forecast can assume to access the Amazon S3 bucket. For more information, see aws-forecast-iam-roles. For more information, see howitworks-forecast. To get a list of all your forecast export jobs, use the ListForecastExportJobs operation.  The Status of the forecast export job must be ACTIVE before you can access the forecast in your Amazon S3 bucket. To get the status, use the DescribeForecastExportJob operation.

    Args:
        forecast_export_job_name(str): The name for the forecast export job.
        forecast_arn(str): The Amazon Resource Name (ARN) of the forecast that you want to export.
        destination(Dict): The location where you want to save the forecast and an AWS Identity and Access Management (IAM) role that Amazon Forecast can assume to access the location. The forecast must be exported to an Amazon S3 bucket. If encryption is used, Destination must include an AWS Key Management Service (KMS) key. The IAM role must allow Amazon Forecast permission to access the key.
        tags(List, optional): The optional metadata that you apply to the forecast export job to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define. The following basic restrictions apply to tags:   Maximum number of tags per resource - 50.   For each resource, each tag key must be unique, and each tag key can have only one value.   Maximum key length - 128 Unicode characters in UTF-8.   Maximum value length - 256 Unicode characters in UTF-8.   If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.   Tag keys and values are case sensitive.   Do not use aws:, AWS:, or any upper or lowercase combination of such as a prefix for keys as it is reserved for AWS use. You cannot edit or delete tag keys with this prefix. Values can have this prefix. If a tag value has aws as its prefix but the key does not, then Forecast considers it to be a user tag and will count against the limit of 50 tags. Tags with only the key prefix of aws do not count against your tags per resource limit.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.forecast.export_job.create(
                ctx, forecast_export_job_name=value, forecast_arn=value, destination=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.forecast.export_job.create forecast_export_job_name=value, forecast_arn=value, destination=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="create_forecast_export_job",
        op_kwargs={
            "ForecastExportJobName": forecast_export_job_name,
            "ForecastArn": forecast_arn,
            "Destination": destination,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, forecast_export_job_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a forecast export job created using the CreateForecastExportJob operation. You can delete only export jobs that have a status of ACTIVE or CREATE_FAILED. To get the status, use the DescribeForecastExportJob operation.

    Args:
        forecast_export_job_arn(str): The Amazon Resource Name (ARN) of the forecast export job to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.forecast.export_job.delete(
                ctx, forecast_export_job_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.forecast.export_job.delete forecast_export_job_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="delete_forecast_export_job",
        op_kwargs={"ForecastExportJobArn": forecast_export_job_arn},
    )


async def describe(hub, ctx, forecast_export_job_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a forecast export job created using the CreateForecastExportJob operation. In addition to listing the properties provided by the user in the CreateForecastExportJob request, this operation lists the following properties:    CreationTime     LastModificationTime     Status     Message - If an error occurred, information about the error.

    Args:
        forecast_export_job_arn(str): The Amazon Resource Name (ARN) of the forecast export job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.forecast.export_job.describe(
                ctx, forecast_export_job_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.forecast.export_job.describe forecast_export_job_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="describe_forecast_export_job",
        op_kwargs={"ForecastExportJobArn": forecast_export_job_arn},
    )


async def list_all(
    hub, ctx, next_token: str = None, max_results: int = None, filters: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of forecast export jobs created using the CreateForecastExportJob operation. For each forecast export job, this operation returns a summary of its properties, including its Amazon Resource Name (ARN). To retrieve the complete set of properties, use the ARN with the DescribeForecastExportJob operation. You can filter the list using an array of Filter objects.

    Args:
        next_token(str, optional): If the result of the previous request was truncated, the response includes a NextToken. To retrieve the next set of results, use the token in the next request. Tokens expire after 24 hours. Defaults to None.
        max_results(int, optional): The number of items to return in the response. Defaults to None.
        filters(List, optional): An array of filters. For each filter, you provide a condition and a match statement. The condition is either IS or IS_NOT, which specifies whether to include or exclude the forecast export jobs that match the statement from the list, respectively. The match statement consists of a key and a value.  Filter properties     Condition - The condition to apply. Valid values are IS and IS_NOT. To include the forecast export jobs that match the statement, specify IS. To exclude matching forecast export jobs, specify IS_NOT.    Key - The name of the parameter to filter on. Valid values are ForecastArn and Status.    Value - The value to match.   For example, to list all jobs that export a forecast named electricityforecast, specify the following filter:  "Filters": [ { "Condition": "IS", "Key": "ForecastArn", "Value": "arn:aws:forecast:us-west-2:<acct-id>:forecast/electricityforecast" } ] . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.forecast.export_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.forecast.export_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="list_forecast_export_jobs",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "Filters": filters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, activity_arn: str, worker_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Used by workers to retrieve a task (with the specified activity ARN) which has been scheduled for execution by a running state machine. This initiates a long poll, where the service holds the HTTP connection open and responds as soon as a task becomes available (i.e. an execution of a task of this type is needed.) The maximum time the service holds on to the request before responding is 60 seconds. If no task is available within 60 seconds, the poll returns a taskToken with a null string.  Workers should set their client side socket timeout to at least 65 seconds (5 seconds higher than the maximum time the service may hold the poll request). Polling with GetActivityTask can cause latency in some implementations. See Avoid Latency When Polling for Activity Tasks in the Step Functions Developer Guide.

    Args:
        activity_arn(str): The Amazon Resource Name (ARN) of the activity to retrieve tasks from (assigned when you create the task using CreateActivity.).
        worker_name(str, optional): You can provide an arbitrary name in order to identify the worker that the task is assigned to. This name is used when it is logged in the execution history. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.stepfunction.activity.task.get(ctx, activity_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.stepfunction.activity.task.get activity_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="stepfunctions",
        operation="get_activity_task",
        op_kwargs={"activityArn": activity_arn, "workerName": worker_name},
    )
